@@ -7,6 +7,8 @@ from pathlib import Path
 import neutronics_material_maker as nmm
 import openmc
 import openmc_dagmc_wrapper as odw
+from dagmc_bounding_box import DagmcBoundingBox
+from remove_dagmc_tags import remove_tags
 
 
 class TestShape(unittest.TestCase):
@@ -60,26 +62,60 @@ class TestShape(unittest.TestCase):
     def test_simulation_with_previous_h5m_file(self):
         """This performs a simulation using previously created h5m file"""
 
+        os.system("rm statepoint.*.h5")
+        os.system("rm summary.h5")
+
         geometry = odw.Geometry(h5m_filename=self.h5m_filename_smaller)
         materials = odw.Materials(
             h5m_filename=self.h5m_filename_smaller,
-            correspondence_dict={"mat1": "WC"})
+            correspondence_dict={
+                "mat1": "WC"})
 
         my_model = openmc.model.Model(
             geometry=geometry,
             materials=materials,
             tallies=[],
-            settings=self.settings
+            settings=self.settings)
+
+        statepoint_file = my_model.run()
+
+        assert Path(statepoint_file).exists()
+
+    def test_simulation_with_previous_h5m_file_with_graveyard_removed(self):
+        """This performs a simulation using previously created h5m file. The
+        graveyard is removed from the geometry"""
+
+        os.system("rm statepoint.*.h5")
+        os.system("rm summary.h5")
+
+        remove_tags(
+            input=self.h5m_filename_smaller,
+            output="no_graveyard_dagmc_file.h5m",
+            tags=["mat:graveyard", "graveyard"],
         )
 
-        h5m_filename = my_model.run()
-        results = odw.process_results(statepoint_filename=h5m_filename)
+        geometry = odw.Geometry(h5m_filename="no_graveyard_dagmc_file.h5m")
+        materials = odw.Materials(
+            h5m_filename="no_graveyard_dagmc_file.h5m",
+            correspondence_dict={"mat1": "WC"},
+        )
 
-        assert results is not None
+        my_model = openmc.model.Model(
+            geometry=geometry,
+            materials=materials,
+            tallies=[],
+            settings=self.settings)
+
+        statepoint_file = my_model.run()
+
+        assert Path(statepoint_file).exists()
 
     def test_neutronics_component_simulation_with_openmc_mat(self):
         """Makes a neutronics model and simulates with a cell tally"""
 
+        os.system("rm statepoint.*.h5")
+        os.system("rm summary.h5")
+
         test_mat = openmc.Material()
         test_mat.add_element("Fe", 1.0)
         test_mat.set_density(units="g/cm3", density=4.2)
@@ -87,7 +123,8 @@ class TestShape(unittest.TestCase):
         geometry = odw.Geometry(h5m_filename=self.h5m_filename_smaller)
         materials = odw.Materials(
             h5m_filename=self.h5m_filename_smaller,
-            correspondence_dict={"mat1": test_mat})
+            correspondence_dict={"mat1": test_mat},
+        )
 
         my_tally = odw.CellTally("heating", target="mat1", materials=materials)
         self.settings.batches = 2
@@ -95,7 +132,7 @@ class TestShape(unittest.TestCase):
             geometry=geometry,
             materials=materials,
             tallies=[my_tally],
-            settings=self.settings
+            settings=self.settings,
         )
         h5m_filename = my_model.run()
         self.settings.batches = 10
@@ -104,21 +141,19 @@ class TestShape(unittest.TestCase):
         results = openmc.StatePoint(h5m_filename)
         assert len(results.tallies.items()) == 1
 
-        results = odw.process_results(
-            statepoint_filename=h5m_filename,
-            fusion_power=1e9)
-        # extracts the heat from the results dictionary
-        assert results[my_tally.name]["Watts"]["result"] > 0
-
     def test_neutronics_component_simulation_with_nmm(self):
         """Makes a neutronics model and simulates with a cell tally"""
 
+        os.system("rm statepoint.*.h5")
+        os.system("rm summary.h5")
+
         test_mat = nmm.Material.from_library("Be")
 
         geometry = odw.Geometry(h5m_filename=self.h5m_filename_smaller)
         materials = odw.Materials(
             h5m_filename=self.h5m_filename_smaller,
-            correspondence_dict={"mat1": test_mat})
+            correspondence_dict={"mat1": test_mat},
+        )
 
         my_tally = odw.CellTally("heating", target=1)
 
@@ -126,7 +161,7 @@ class TestShape(unittest.TestCase):
             geometry=geometry,
             materials=materials,
             tallies=[my_tally],
-            settings=self.settings
+            settings=self.settings,
         )
 
         h5m_filename = my_model.run()
@@ -134,15 +169,10 @@ class TestShape(unittest.TestCase):
         results = openmc.StatePoint(h5m_filename)
         assert len(results.tallies.items()) == 1
 
-        results = odw.process_results(
-            statepoint_filename=h5m_filename,
-            fusion_power=1e9)
-        # extracts the heat from the results dictionary
-        assert results[my_tally.name]["Watts"]["result"] > 0
-
     def test_incorrect_cell_tallies(self):
         """Set a cell tally that is not accepted which should raise an
         error"""
+
         def incorrect_cell_tallies():
             odw.CellTally("coucou")
 
@@ -151,6 +181,7 @@ class TestShape(unittest.TestCase):
     def test_incorrect_cell_tally_type(self):
         """Set a cell tally that is the wrong type which should raise an
         error"""
+
         def incorrect_cell_tally_type():
             odw.CellTally(1)
 
@@ -159,7 +190,9 @@ class TestShape(unittest.TestCase):
     def test_neutronics_component_cell_simulation_heating(self):
         """Makes a neutronics model and simulates with a cell tally"""
 
-        os.system("rm *.h5")
+        os.system("rm statepoint.*.h5")
+        os.system("rm summary.h5")
+
         mat = openmc.Material()
         mat.add_element("Li", 1)
         mat.set_density("g/cm3", 2.1)
@@ -167,7 +200,8 @@ class TestShape(unittest.TestCase):
         geometry = odw.Geometry(h5m_filename=self.h5m_filename_smaller)
         materials = odw.Materials(
             h5m_filename=self.h5m_filename_smaller,
-            correspondence_dict={"mat1": mat})
+            correspondence_dict={
+                "mat1": mat})
         my_tallies = odw.CellTallies(
             tally_types=[
                 "heating",
@@ -180,7 +214,7 @@ class TestShape(unittest.TestCase):
             geometry=geometry,
             materials=materials,
             tallies=my_tallies.tallies,
-            settings=self.settings
+            settings=self.settings,
         )
         # performs an openmc simulation on the model
         h5m_filename = my_model.run()
@@ -190,31 +224,12 @@ class TestShape(unittest.TestCase):
         assert len(results.tallies.items()) == 5
         assert len(results.meshes) == 0
 
-        results = odw.process_results(
-            statepoint_filename=h5m_filename,
-            fusion_power=1e9
-        )
-
-        # extracts the heat from the results dictionary
-        print(results['mat1_heating'])
-        heat = results["heating"]["Watts"]["result"]
-        flux = results["flux"]["flux per source particle"]["result"]
-        tbr = results["TBR"]["result"]
-        spectra_neutrons = results["neutron_spectra"]["flux per source particle"]["result"]
-        spectra_photons = results["photon_spectra"]["flux per source particle"]["result"]
-        energy = results["photon_spectra"]["flux per source particle"]["energy"]
-
-        assert heat > 0
-        assert flux > 0
-        assert tbr > 0
-        assert len(energy) == 710
-        assert len(spectra_neutrons) == 709
-        assert len(spectra_photons) == 709
-
-    def test_neutronics_spectra_post_processing(self):
+    def test_neutronics_spectra(self):
         """Makes a neutronics model and simulates with a cell tally"""
 
-        os.system("rm *.h5")
+        os.system("rm statepoint.*.h5")
+        os.system("rm summary.h5")
+
         mat = openmc.Material()
         mat.add_element("Li", 1)
         mat.set_density("g/cm3", 2.1)
@@ -222,98 +237,48 @@ class TestShape(unittest.TestCase):
         geometry = odw.Geometry(h5m_filename=self.h5m_filename_smaller)
         materials = odw.Materials(
             h5m_filename=self.h5m_filename_smaller,
-            correspondence_dict={"mat1": mat})
+            correspondence_dict={
+                "mat1": mat})
         my_tallies = odw.CellTallies(
-            tally_types=["neutron_spectra", "photon_spectra"])
+            tally_types=[
+                "neutron_spectra",
+                "photon_spectra"])
 
         my_model = openmc.model.Model(
             geometry=geometry,
             materials=materials,
             tallies=my_tallies.tallies,
-            settings=self.settings
+            settings=self.settings,
         )
 
         # performs an openmc simulation on the model
-        h5m_filename = my_model.run()
+        statepoint_file = my_model.run()
 
-        results = odw.process_results(statepoint_filename=h5m_filename)
-        assert len(results.keys()) == 2
-        assert len(results['neutron_spectra'].keys()) == 1
-        assert len(results['photon_spectra'].keys()) == 1
-
-        neutron_flux_sum = sum(results['neutron_spectra']
-                               ["flux per source particle"]["result"])
-        photon_flux_sum = sum(results['photon_spectra']
-                              ["flux per source particle"]["result"])
-
-        # TODO change > to the actual ratio
-
-        results = odw.process_results(
-            statepoint_filename=h5m_filename,
-            fusion_energy_per_pulse=3)
-        assert len(results.keys()) == 2
-        assert len(results['neutron_spectra'].keys()) == 2
-        assert len(results['photon_spectra'].keys()) == 2
-        assert sum(results['neutron_spectra']
-                   ['flux per pulse']['result']) > neutron_flux_sum
-        assert sum(results['photon_spectra']
-                   ['flux per pulse']['result']) > photon_flux_sum
-
-        results = odw.process_results(
-            statepoint_filename=h5m_filename,
-            fusion_power=2)
-        assert len(results.keys()) == 2
-        assert len(results['neutron_spectra'].keys()) == 2
-        assert len(results['photon_spectra'].keys()) == 2
-        assert sum(results['neutron_spectra']
-                   ['flux per second']['result']) > neutron_flux_sum
-        assert sum(results['photon_spectra']
-                   ['flux per second']['result']) > photon_flux_sum
-
-        results = odw.process_results(
-            statepoint_filename=h5m_filename,
-            fusion_energy_per_pulse=2,
-            fusion_power=3)
-        assert len(results.keys()) == 2
-        assert len(results['neutron_spectra'].keys()) == 3
-        assert len(results['photon_spectra'].keys()) == 3
-        assert sum(results['neutron_spectra']
-                   ['flux per pulse']['result']) > neutron_flux_sum
-        assert sum(results['photon_spectra']
-                   ['flux per pulse']['result']) > photon_flux_sum
-        assert sum(results['neutron_spectra']
-                   ['flux per second']['result']) > neutron_flux_sum
-        assert sum(results['photon_spectra']
-                   ['flux per second']['result']) > photon_flux_sum
-
-        spectra_neutrons = results["neutron_spectra"]["flux per source particle"]["result"]
-        spectra_photons = results["photon_spectra"]["flux per source particle"]["result"]
-        energy = results["photon_spectra"]["flux per source particle"]["energy"]
-
-        assert len(energy) == 710
-        assert len(spectra_neutrons) == 709
-        assert len(spectra_photons) == 709
+        assert Path(statepoint_file).exists()
 
     def test_neutronics_component_2d_mesh_simulation(self):
         """Makes a neutronics model and simulates with a 2D mesh tally"""
 
-        os.system("rm *_on_2D_mesh_*.png")
-        os.system("rm *.h5")
+        os.system("rm statepoint.*.h5")
+        os.system("rm summary.h5")
 
         geometry = odw.Geometry(h5m_filename=self.h5m_filename_smaller)
         materials = odw.Materials(
             h5m_filename=self.h5m_filename_smaller,
-            correspondence_dict={"mat1": "Be"})
+            correspondence_dict={
+                "mat1": "Be"})
+
         my_tallies = odw.MeshTallies2D(
             tally_types=["heating"],
             planes=["xy", "xz", "yz"],
-            bounding_box=self.h5m_filename_smaller)
+            bounding_box=DagmcBoundingBox(self.h5m_filename_smaller).corners(),
+        )
 
         my_model = openmc.model.Model(
             geometry=geometry,
             materials=materials,
             tallies=my_tallies.tallies,
-            settings=self.settings
+            settings=self.settings,
         )
         # performs an openmc simulation on the model
         h5m_filename = my_model.run()
@@ -323,78 +288,71 @@ class TestShape(unittest.TestCase):
         assert len(results.meshes) == 3
         assert len(results.tallies.items()) == 3
 
-        assert Path("heating_on_2D_mesh_xz.png").exists() is False
-        assert Path("heating_on_2D_mesh_xy.png").exists() is False
-        assert Path("heating_on_2D_mesh_yz.png").exists() is False
-
-        odw.process_results(statepoint_filename=h5m_filename, fusion_power=1e9)
-
-        assert Path("heating_on_2D_mesh_xz.png").exists() is True
-        assert Path("heating_on_2D_mesh_xy.png").exists() is True
-        assert Path("heating_on_2D_mesh_yz.png").exists() is True
-
     def test_neutronics_component_3d_mesh_simulation(self):
         """Makes a neutronics model and simulates with a 3D mesh tally and
         checks that the vtk file is produced"""
 
-        os.system("rm *.h5 *.vtk")
+        os.system("rm statepoint.*.h5")
+        os.system("rm summary.h5")
+        os.system("rm *.vtk")
 
         geometry = odw.Geometry(h5m_filename=self.h5m_filename_smaller)
         materials = odw.Materials(
             h5m_filename=self.h5m_filename_smaller,
-            correspondence_dict={"mat1": "Be"})
+            correspondence_dict={
+                "mat1": "Be"})
 
         my_tallies = odw.MeshTallies3D(
             tally_types=["heating", "(n,Xt)"],
-            bounding_box=self.h5m_filename_smaller)
+            bounding_box=DagmcBoundingBox(self.h5m_filename_smaller).corners(),
+        )
 
         my_model = openmc.model.Model(
             geometry=geometry,
             materials=materials,
             tallies=my_tallies.tallies,
-            settings=self.settings
+            settings=self.settings,
         )
         # performs an openmc simulation on the model
         h5m_filename = my_model.run()
 
         results = openmc.StatePoint(h5m_filename)
-        assert len(results.meshes) == 1
+        # ideally these tallies would share the same mesh and there would be 1
+        # mesh
+        assert len(results.meshes) == 2
         assert len(results.tallies.items()) == 2
         assert Path(h5m_filename).exists() is True
 
-        assert Path("heating_on_3D_mesh.vtk").exists() is False
-        assert Path("n-Xt_on_3D_mesh.vtk").exists() is False
-
-        odw.process_results(statepoint_filename=h5m_filename, fusion_power=1e9)
-
-        assert Path("heating_on_3D_mesh.vtk").exists() is True
-        assert Path("n-Xt_on_3D_mesh.vtk").exists() is True
-
     def test_neutronics_component_3d_and_2d_mesh_simulation(self):
         """Makes a neutronics model and simulates with a 3D and 2D mesh tally
         and checks that the vtk and png files are produced. This checks the
         mesh ID values don't overlap"""
 
-        os.system("rm *.h5")
+        os.system("rm statepoint.*.h5")
+        os.system("rm summary.h5")
 
         geometry = odw.Geometry(h5m_filename=self.h5m_filename_smaller)
         materials = odw.Materials(
             h5m_filename=self.h5m_filename_smaller,
-            correspondence_dict={"mat1": "Be"})
+            correspondence_dict={
+                "mat1": "Be"})
 
         my_3d_tally = odw.MeshTally3D(
-            tally_type="heating", bounding_box=self.h5m_filename_smaller)
+            tally_type="heating",
+            bounding_box=DagmcBoundingBox(self.h5m_filename_smaller).corners(),
+        )
 
         my_2d_tallies = odw.MeshTallies2D(
             planes=["xz", "xy", "yz"],
             tally_types=["heating"],
-            bounding_box=self.h5m_filename_smaller)
+            bounding_box=DagmcBoundingBox(self.h5m_filename_smaller).corners(),
+        )
 
         my_model = openmc.model.Model(
             geometry=geometry,
             materials=materials,
             tallies=[my_3d_tally] + my_2d_tallies.tallies,
-            settings=self.settings
+            settings=self.settings,
         )
         # performs an openmc simulation on the model
         h5m_filename = my_model.run()
@@ -403,26 +361,20 @@ class TestShape(unittest.TestCase):
         assert len(results.meshes) == 4  # one 3D and three 2D
         assert len(results.tallies.items()) == 4  # one 3D and three 2D
 
-        odw.process_results(statepoint_filename=h5m_filename, fusion_power=1e9)
-
-        assert Path(h5m_filename).exists() is True
-        assert Path("heating_on_3D_mesh.vtk").exists() is True
-        assert Path("heating_on_2D_mesh_xz.png").exists() is True
-        assert Path("heating_on_2D_mesh_xy.png").exists() is True
-        assert Path("heating_on_2D_mesh_yz.png").exists() is True
-
     def test_neutronics_component_3d_and_2d_mesh_simulation_with_corner_points(
             self):
         """Makes a neutronics model and simulates with a 3D and 2D mesh tally
         and checks that the vtk and png files are produced. This checks the
         mesh ID values don't overlap"""
 
-        os.system("rm *.h5")
+        os.system("rm statepoint.*.h5")
+        os.system("rm summary.h5")
 
         geometry = odw.Geometry(h5m_filename=self.h5m_filename_smaller)
         materials = odw.Materials(
             h5m_filename=self.h5m_filename_smaller,
-            correspondence_dict={"mat1": "Be"})
+            correspondence_dict={
+                "mat1": "Be"})
 
         my_3d_tally = odw.MeshTally3D(
             tally_type="heating",
@@ -432,7 +384,7 @@ class TestShape(unittest.TestCase):
         my_2d_tallies = odw.MeshTallies2D(
             planes=["xz", "xy", "yz"],
             tally_types=["heating"],
-            bounding_box=[(5, 5, 5), (15, 15, 15)]
+            bounding_box=[(5, 5, 5), (15, 15, 15)],
         )
 
         assert my_3d_tally.bounding_box == [(0, 0, 0), (10, 10, 10)]
@@ -443,7 +395,7 @@ class TestShape(unittest.TestCase):
             geometry=geometry,
             materials=materials,
             tallies=[my_3d_tally] + my_2d_tallies.tallies,
-            settings=self.settings
+            settings=self.settings,
         )
 
         # performs an openmc simulation on the model
@@ -453,203 +405,96 @@ class TestShape(unittest.TestCase):
         assert len(results.meshes) == 4  # one 3D and three 2D
         assert len(results.tallies.items()) == 4  # one 3D and three 2D
 
-        odw.process_results(statepoint_filename=h5m_filename, fusion_power=1e9)
-
-        assert Path(h5m_filename).exists() is True
-        assert Path("heating_on_3D_mesh.vtk").exists() is True
-        assert Path("heating_on_2D_mesh_xz.png").exists() is True
-        assert Path("heating_on_2D_mesh_xy.png").exists() is True
-        assert Path("heating_on_2D_mesh_yz.png").exists() is True
-
     def test_reactor_from_shapes_cell_tallies(self):
         """Makes a reactor from two shapes, then makes a neutronics model
         and tests the TBR simulation value"""
 
-        os.system("rm results.json")
+        os.system("rm statepoint.*.h5")
+        os.system("rm summary.h5")
 
         geometry = odw.Geometry(h5m_filename=self.h5m_filename_smaller)
         materials = odw.Materials(
             h5m_filename=self.h5m_filename_smaller,
-            correspondence_dict={"mat1": "Be"})
+            correspondence_dict={
+                "mat1": "Be"})
 
-        my_tallies = odw.CellTallies(
-            tally_types=["TBR", "heating", "flux"])
+        my_tallies = odw.CellTallies(tally_types=["TBR", "heating", "flux"])
 
         my_model = openmc.model.Model(
             geometry=geometry,
             materials=materials,
             tallies=my_tallies.tallies,
-            settings=self.settings
+            settings=self.settings,
         )
 
         # performs an openmc simulation on the model
-        h5m_filename = my_model.run()
+        statepoint_file = my_model.run()
 
-        results = odw.process_results(
-            statepoint_filename=h5m_filename,
-            fusion_power=1e9
-        )
-
-        assert isinstance(results["TBR"]["result"], float)
-        assert Path("results.json").exists() is True
+        assert Path(statepoint_file).exists()
 
     def test_cell_tallies_simulation_fast_flux(self):
         """Performs simulation with h5m file and tallies neutron and photon
         fast flux. Checks that entries exist in the results."""
 
-        os.system("rm results.json")
+        os.system("rm statepoint.*.h5")
+        os.system("rm summary.h5")
 
         geometry = odw.Geometry(h5m_filename=self.h5m_filename_smaller)
         materials = odw.Materials(
             h5m_filename=self.h5m_filename_smaller,
-            correspondence_dict={"mat1": "Be"})
+            correspondence_dict={
+                "mat1": "Be"})
 
         my_tallies = odw.CellTallies(
-            tally_types=["photon_fast_flux", "neutron_fast_flux", "flux"])
+            tally_types=["photon_fast_flux", "neutron_fast_flux", "flux"]
+        )
 
         my_model = openmc.model.Model(
             geometry=geometry,
             materials=materials,
             tallies=my_tallies.tallies,
-            settings=self.settings
+            settings=self.settings,
         )
 
         # performs an openmc simulation on the model
-        h5m_filename = my_model.run()
+        statepoint_file = my_model.run()
 
-        results = odw.process_results(
-            statepoint_filename=h5m_filename,
-            fusion_power=1e9,
-            fusion_energy_per_pulse=1.2e6
-        )
-
-        assert isinstance(
-            results["neutron_fast_flux"]["fast flux per source particle"]["result"],
-            float,
-        )
-        assert isinstance(
-            results["flux"]["flux per source particle"]["result"],
-            float,
-        )
-
-        assert results["flux"]["flux per source particle"]["result"] > results[
-            "neutron_fast_flux"]["fast flux per source particle"]["result"]
+        assert Path(statepoint_file).exists()
 
     def test_cell_tallies_simulation_effective_dose(self):
         """Performs simulation with h5m file and tallies neutron and photon
         dose. Checks that entries exist in the results."""
 
-        os.system("rm results.json statepoint*.h5")
+        os.system("rm statepoint.*.h5")
+        os.system("rm summary.h5")
 
         geometry = odw.Geometry(h5m_filename=self.h5m_filename_smaller)
         materials = odw.Materials(
             h5m_filename=self.h5m_filename_smaller,
-            correspondence_dict={"mat1": "Be"})
+            correspondence_dict={
+                "mat1": "Be"})
 
         my_tallies = odw.CellTallies(
-            tally_types=["photon_effective_dose", "neutron_effective_dose"])
+            tally_types=["photon_effective_dose", "neutron_effective_dose"]
+        )
 
         my_model = openmc.model.Model(
             geometry=geometry,
             materials=materials,
             tallies=my_tallies.tallies,
-            settings=self.settings
+            settings=self.settings,
         )
 
         # performs an openmc simulation on the model
-        h5m_filename = my_model.run()
+        statepoint_file = my_model.run()
 
-        results = odw.process_results(
-            statepoint_filename=h5m_filename,
-            fusion_power=1e9,
-            fusion_energy_per_pulse=1.2e6
-        )
-
-        assert isinstance(
-            results["neutron_effective_dose"][
-                "effective dose per source particle pSv cm3"
-            ]["result"],
-            float,
-        )
-        assert isinstance(
-            results["neutron_effective_dose"][
-                "pSv cm3 per pulse"
-            ]["result"],
-            float,
-        )
-        assert isinstance(
-            results["neutron_effective_dose"][
-                "pSv cm3 per second"
-            ]["result"],
-            float,
-        )
-
-        assert isinstance(
-            results["neutron_effective_dose"][
-                "effective dose per source particle pSv cm3"
-            ]["std. dev."],
-            float,
-        )
-        assert isinstance(
-            results["neutron_effective_dose"][
-                "pSv cm3 per pulse"
-            ]["std. dev."],
-            float,
-        )
-        assert isinstance(
-            results["neutron_effective_dose"][
-                "pSv cm3 per second"
-            ]["std. dev."],
-            float,
-        )
-
-        assert isinstance(
-            results["photon_effective_dose"][
-                "effective dose per source particle pSv cm3"
-            ]["result"],
-            float,
-        )
-        assert isinstance(
-            results["photon_effective_dose"]["pSv cm3 per pulse"][
-                "result"
-            ],
-            float,
-        )
-        assert isinstance(
-            results["photon_effective_dose"][
-                "pSv cm3 per second"
-            ]["result"],
-            float,
-        )
-
-        assert isinstance(
-            results["photon_effective_dose"][
-                "effective dose per source particle pSv cm3"
-            ]["std. dev."],
-            float,
-        )
-        assert isinstance(
-            results["photon_effective_dose"]["pSv cm3 per pulse"][
-                "std. dev."
-            ],
-            float,
-        )
-        assert isinstance(
-            results["photon_effective_dose"][
-                "pSv cm3 per second"
-            ]["std. dev."],
-            float,
-        )
-
-        assert Path("results.json").exists() is True
+        assert Path(statepoint_file).exists()
 
     # @shimwell can you take a look at that please?
     # def test_reactor_from_shapes_2d_mesh_tallies(self):
     #     """Makes a reactor from two shapes, then makes a neutronics model
     #     and tests the TBR simulation value"""
 
-    #     os.system("rm *_on_2D_mesh_*.png")
-
     #     geometry = odw.Geometry(h5m_filename=self.h5m_filename_smaller)
     #     materials = odw.Materials(
     #         h5m_filename=self.h5m_filename_smaller,
@@ -666,19 +511,9 @@ class TestShape(unittest.TestCase):
     #     )
 
     #     # performs an openmc simulation on the model
-    #     h5m_filename = my_model.run()
+    # statepoint_file = my_model.run()
 
-    #     odw.process_results(statepoint_filename=h5m_filename, fusion_power=1e9)
-
-    #     assert Path("n-Xt_on_2D_mesh_xz.png").exists() is True
-    #     assert Path("n-Xt_on_2D_mesh_xy.png").exists() is True
-    #     assert Path("n-Xt_on_2D_mesh_yz.png").exists() is True
-    #     assert Path("heating_on_2D_mesh_xz.png").exists() is True
-    #     assert Path("heating_on_2D_mesh_xy.png").exists() is True
-    #     assert Path("heating_on_2D_mesh_yz.png").exists() is True
-    #     assert Path("flux_on_2D_mesh_xz.png").exists() is True
-    #     assert Path("flux_on_2D_mesh_xy.png").exists() is True
-    #     assert Path("flux_on_2D_mesh_yz.png").exists() is True
+    # assert Path(statepoint_file).exists()
 
     def test_simulations_with_missing_h5m_files(self):
         """Creates NeutronicsModel objects and tries to perform simulation
@@ -689,7 +524,8 @@ class TestShape(unittest.TestCase):
             should fail with a FileNotFoundError"""
 
             import shutil
-            shutil.copy(self.h5m_filename_smaller, '.')
+
+            shutil.copy(self.h5m_filename_smaller, ".")
 
             # creates xml files so that the code passes the xml file check
             os.system("touch geometry.xml")
@@ -700,8 +536,8 @@ class TestShape(unittest.TestCase):
 
             odw.Materials(
                 h5m_filename="dagmc.h5m",
-                correspondence_dict={"mat1": "Be"}
-            )
+                correspondence_dict={
+                    "mat1": "Be"})
 
         self.assertRaises(
             FileNotFoundError,
